#
# spec file for package python-django-codemod
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-django-codemod
Version:        1.11.0
Release:        1.13
Summary:        Collections of libCST codemodders to upgrade Django
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/browniebroke/django-codemod
Source:         https://files.pythonhosted.org/packages/source/d/django-codemod/django-codemod-%{version}.tar.gz
Source1:        conftest.py
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires:       python-libcst
Requires:       python-pathspec
Requires:       python-rich-click
Recommends:     python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module libcst}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pathspec}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module rich-click}
# /SECTION
%python_subpackages

%description
Collections of libCST codemodders to upgrade Django.

%prep
%setup -q -n django-codemod-%{version}
cp %{SOURCE1} .
sed -i 's/rich = ".*"/rich = "*"/' pyproject.toml
sed -i '/addopts/d' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/djcodemod
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative djcodemod

%postun
%python_uninstall_alternative djcodemod

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/djcodemod
%{python_sitelib}/*django[_-]codemod*/

%changelog
* Wed Aug 31 2022 John Vandenberg <jayvdb@gmail.com>
- Added conftest.py from upstream
- Update to v1.11.0
  * Add tests to sdist
- from v1.10.1
  * Revert to libCST old parser
- from v1.10.0
  * Add support for Python 3.10 (92e9bcd)
  * Use libCST's native parser
- from v1.9.0
  * Integrate rich-click
- from v1.8.0
  * Drop support for Python 3.6
* Mon Jan 10 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.7.0
  * Avoid imports in try blocks
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sat Dec 25 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v1.6.6
- from v1.6.0
  * Support admin's ACTION_CHECKBOX_NAME compatibility import removal
  * Support BaseContext, Context, ContextPopException and
    RequestContext compatibility imports removal
  * Support for BoundField compatibility import removal
  * Support for pretty_name compatibility import removal
  * Support for FieldDoesNotExist compatibility import removal
  * Support for EmptyResultSet compatibility imports removal
- from v1.5.7
  * Rewrite parent module renaming logic
- from v1.5.6
  * Disable rename parent module imported
- from v1.5.4
  * Issue with command shadowing built-in
  * Add a missing type hints in cli
  * Type checking error
- from v1.5.1
  * Avoid extra spaces around kwargs in InlineHasAddPermissionsTransformer
- from v1.5.0
  * Handle deprecation for NullBooleanField
  * Avoid spaces around kwarg in FixedOffsetTransformer
  * Avoid extra whitespaces in kwargs from OnDeleteTransformer
- from v1.4.1
  * Update type annotations
- from v1.4.0
  * Handle rename when parent module is imported
- from v1.3.6
  * Mypy issues when following imports
  * Type hint issues
  * Error with star import
- from v1.3.4
  * Don't confuse kwargs with symbol to codemod
- from v1.3.3
  * Bug with attributes accessing
  * Bug with scopes
  * Add some missing type hints
- from v1.3.2
  * Bug when url() route uses the regex kwarg
- from v1.3.1
  * Support another slug pattern
  * Migrate partial patterns to path
- from v1.3.0
  * Add fixer for django.utils.http.cookie_date
- from v1.2.0
  * Make it runnable as pre-commit hook
- from v1.1.0
  * Ignore files according to .gitignore
* Thu Nov 26 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v1.0.0
  * See https://github.com/browniebroke/django-codemod/compare/v0.13.0...v1.0.0
* Sat Aug  8 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.13.0
* Fri Jul  3 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.9.0
